@@ -12,5 +12,5 @@ mcmc2bugs <- function(x, model.file = NULL, program = "", DIC = FALSE,
   }
   ans <- as.bugs.array(sims.array, model.file=model.file, program=program, DIC=DIC, 
     DICOutput=DICOutput, n.iter=n.iter, n.burnin=n.burnin, n.thin=n.thin)
-  ans
+  return(ans)
 }
